import request from '@/utils/request'

// 查询引擎列表
export function listConfig(query) {
  return request({
    url: '/rule/config/list',
    method: 'get',
    params: query
  })
}

// 查询引擎列表
export function listConfigEs(ruleId) {
  return request({
    url: '/rule/config/listConfigEs/' + ruleId,
    method: 'post'
  })
}

// 查询引擎详细
export function getConfig(id) {
  return request({
    url: '/rule/config/' + id,
    method: 'get'
  })
}

// 新增引擎
export function addConfig(data) {
  return request({
    url: '/rule/config',
    method: 'post',
    data: data
  })
}

// 修改引擎
export function updateConfig(data) {
  return request({
    url: '/rule/config',
    method: 'put',
    data: data
  })
}

// 删除引擎
export function delConfig(id) {
  return request({
    url: '/rule/config/' + id,
    method: 'delete'
  })
}
// 测试
export function textData(data) {
  return request({
    url: '/rule/config/testData',
    method: 'post',
    data
  })
}
// 通过引擎作用域编号获取引擎配置作用域信息
export function getScopeInfo(id) {
  return request({
    url: '/rule/config/getScopeInfo/' + id,
    method: 'post'
  })
}

export function queryConfigInfo(id) {
  return request({
    url: '/rule/config/queryConfigInfo/' + id,
    method: 'post'
  })
}
